<?php
/* add_ons_php */

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

// redirect page for dashboard
function easybook_addons_dashboard_page_template_redirect(){
    $dashboard_page_id = esb_addons_get_wpml_option('dashboard_page');  
    if( ($dashboard_page_id && is_page( $dashboard_page_id )) )
    {
        if (! is_user_logged_in()) {
            wp_redirect( home_url( '/' ) ); 
            die;
        }
            
    }
}
add_action( 'template_redirect', 'easybook_addons_dashboard_page_template_redirect' );

/*
https://wordpress.stackexchange.com/questions/192360/current-user-can-edit-post-post-id-does-not-work-for-contributer-but-for
https://codex.wordpress.org/Function_Reference/map_meta_cap
https://developer.wordpress.org/reference/hooks/map_meta_cap/
https://wordpress.stackexchange.com/questions/108338/capabilities-and-custom-post-types
https://wordpress.stackexchange.com/questions/65418/admins-cant-edit-each-others-posts
*/
function easybook_addons_map_meta_cap( $caps, $cap, $user_id, $args ){
    if ( 'edit_post' == $cap ) {
        $post = get_post( $args[0] );
        $post_type = get_post_type_object( $post->post_type );
        $caps = array();
        if ( $user_id == $post->post_author )
            $caps[] = $post_type->cap->edit_posts;
        else
            $caps[] = $post_type->cap->edit_others_posts;
    }
    return $caps;
}
add_filter( 'map_meta_cap', 'easybook_addons_map_meta_cap', 10, 4 );



function easybook_addons_maintenance_mode() {
    global $pagenow;
    $mode = easybook_addons_get_option('maintenance_mode');
    $demo_mode = isset($_GET['demo_mode'])? $_GET['demo_mode'] : '';
    if ( $pagenow !== 'wp-login.php' && ! current_user_can( 'manage_options' ) && ! is_admin() && ($mode == 'maintenance'||$mode=='coming_soon'||$demo_mode =='maintenance'||$demo_mode =='coming_soon') ) {
        // wp_redirect( home_url( ) );// redirect to home page first
        header( $_SERVER["SERVER_PROTOCOL"] . __( ' 503 Service Temporarily Unavailable', 'easybook-add-ons' ), true, 503 );
        header( 'Content-Type: text/html; charset=utf-8' );
        if($mode == 'coming_soon'||$demo_mode =='coming_soon'){
            easybook_addons_get_template_part('templates/coming_soon');
        }else{
            header( 'Retry-After: 3600' );
            easybook_addons_get_template_part('templates/maintenance');
        } 
        // wp_die();
        die;
    }
    $current_user = wp_get_current_user();
    if( !is_admin() && 0 == $current_user->ID ){
        add_action( 'wp_footer', 'easybook_addons_print_login_modal' );
    }
}

add_action( 'wp_loaded', 'easybook_addons_maintenance_mode' );

if(!function_exists('easybook_addons_login_logout_sc')){
    function easybook_addons_login_logout_sc($atts, $content = ''){

        extract(shortcode_atts(array(
               'show_register' =>esc_html_x( 'no', 'Show register button: yes or no', 'easybook-add-ons' ),
               'show_register_when_logged_in'=>'no',
               'style'=>'two',
               'extraclass'=>''
         ), $atts));

        

        ob_start();
        // check if the user already login - the correct way is using is_user_logged_in()
        $current_user = wp_get_current_user();
        if ( 0 == $current_user->ID ) {
            // Not logged in.
            ?>
            <?php if($show_register == 'yes'){ ?>
            <div class="show-reg-form logreg-modal-open"><?php _e('<i class="fa fa-lock"></i>Register','easybook-add-ons');?></div>
            <?php } ?>
            <div class="show-reg-form logreg-modal-open"><?php _e('<i class="fa fa-sign-in"></i>Sign In','easybook-add-ons');?></div>
        <?php
        } else {
            // Logged in.
            easybook_addons_get_template_part('template-parts/shortcodes/user', 'menu', array('style' => $style, 'current_user' => $current_user));
        }
        $output = ob_get_clean();

        // if ( 0 == $current_user->ID ){
        //     add_action( 'wp_footer', 'easybook_addons_print_login_modal' );
        // } 
        // add_action( 'wp_footer', 'easybook_addons_single_map_modal' );

        return $output;

    }

    add_shortcode( 'easybook_login', 'easybook_addons_login_logout_sc' );
}

function easybook_addons_print_login_modal(){
    easybook_addons_get_template_part('template-parts/shortcodes/login-modal');
}
add_action( 'wp_footer', 'easybook_addons_single_map_modal' );
function easybook_addons_single_map_modal(){
    $smclass = 'singleMap';
    if(easybook_addons_get_option('use_osm_map') == 'yes') $smclass = 'singleMapOSM';
    ?>
    <!--map-modal -->
    <div class="map-modal-wrap">
        <div class="map-modal-wrap-overlay"></div>
        <div class="map-modal-item">
            <div class="map-modal-container fl-wrap">
                <div class="map-modal fl-wrap">
                    <div class="<?php echo $smclass; ?>" data-lat="<?php echo easybook_addons_get_option('gmap_default_lat'); ?>" data-lng="<?php echo easybook_addons_get_option('gmap_default_long'); ?>" data-loc=""></div>
                </div>
                <h3><i class="fal fa-location-arrow"></i><a href="#"><?php _e( 'Hotel Title', 'easybook-add-ons' ); ?></a></h3>
                <div class="map-modal-close"><i class="fal fa-times"></i></div>
            </div>
        </div>
    </div>
    <!--map-modal end --> 
    <!--ajax-modal-container-->
    <div class="ajax-modal-overlay"></div>
    <div class="ajax-modal-container">
        <!--ajax-modal -->
        <div class='ajax-loader'>
            <div class='ajax-loader-cirle'></div>
        </div>
        <div id="ajax-modal" class="fl-wrap"></div><!--#ajax-modal end -->
    </div>
    <!--ajax-modal-container end -->
    <script type="text/template" id="tmpl-bookmarks-whis">       
       <#
       _.each(data, function(data){ #>   
            <li class="clearfix wishlist-item fl-wrap cth-table-list">
                <a href="#" class="delete-bookmark-btn" data-id="{{data.id}}"><i class="fal fa-times-circle"></i></a>
                <div class="wishlist-sec"> 
                    <a href="{{data.url}}"  class="widget-posts-img"><img src="{{data.thub}}" class="respimg" alt=""></a>
                    <div class="widget-posts-descr">
                        <a href="{{data.url}}">{{{data.title}}}</a>
                        <div class="listing-rating card-popup-rainingvis"data-starrating2="{{data.rating['sum']}}" data-stars="{{data.rating_base}}"></div>                                            
                        <div class="geodir-category-location fl-wrap"><a href="#"><i class="fas fa-map-marker-alt"></i>{{{data.address}}}</a></div>
                        <span class="rooms-price"> $ {{{data.price_from}}}<strong><?php esc_html_e(' /  Avg','easybook-add-ons'); ?></strong></span>
                    </div>
                </div>           
            </li>
        <# }) #>
    </script>
    <?php
}
if(!function_exists('easybook_addons_submit_button_sc')){
    function easybook_addons_submit_button_sc($atts, $content = ''){

        if( easybook_addons_get_option('always_show_submit') != 'yes' ) return;
        ob_start();

        easybook_addons_get_template_part('template-parts/shortcodes/add-list');
        
        
        $output = ob_get_clean();
        return $output;

    }

    add_shortcode( 'easybook_submit_button', 'easybook_addons_submit_button_sc' ); 
}
// search header top shortcode
if(!function_exists('easybook_addons_search_header_top_sc')){
    function easybook_addons_search_header_top_sc($atts, $content = ''){
        ob_start();
        ?>
            <div class="header-search vis-search">
                <div class="container">
                    <div class="row">
                        <form role="search" method="get" action="<?php echo esc_url(home_url( '/' ) ); ?>" class="list-search-header-form">
                            <?php 
                                echo easybook_addons_azp_parser_listing( false , 'filter_header');
                            ?>    
                        </form>                                                        
                    </div>
                </div>
                <div class="close-header-search"><i class="fa fa-angle-double-up"></i></div>
            </div>
        <?php
        $output = ob_get_clean();

        
        return $output;

    }

    add_shortcode( 'easybook_search_header_top', 'easybook_addons_search_header_top_sc' );  
}

// Currency list shortcode
if(!function_exists('easybook_addons_currencies_switcher_sc')){
    function easybook_addons_currencies_switcher_sc($atts, $content = '') {
        ob_start();
        $curr_attrs = easybook_addons_get_currency_attrs();
        $currencies = easybook_addons_get_option('currencies');
        ?>
        <div class="currency-wrap">
            <div class="show-currency-tooltip"><i class="currency-symbol"><?php echo $curr_attrs['symbol']; ?></i><span><?php echo $curr_attrs['currency']; ?><i class="fa fa-caret-down"></i></span></div>
            <ul class="currency-tooltip currency-switcher">
                <?php 
                if(is_array($currencies) && !empty($currencies)){
                    $base_curr = easybook_addons_get_base_currency();
                    $currencies = array_merge($currencies, array( $base_curr ) );
                    foreach ($currencies as $key => $val) { 
                        if(is_array($val) && isset($val['currency']) && $val['currency'] !== $curr_attrs['currency'] ) {
                        ?>
                        <li><a class="currency-item" href="<?php echo add_query_arg( 'currency', $val['currency'] ); ?>"><i class="currency-symbol"><?php echo $val['symbol'] ?></i><?php echo $val['currency'] ?></a></li>
                        <?php
                        }
                    }
                }
                ?>
            </ul>
        </div>
        <?php
        $output = ob_get_clean();
        return $output;
    }
    add_shortcode( 'currency_list', 'easybook_addons_currencies_switcher_sc' ); 
    add_shortcode( 'currencies_switcher', 'easybook_addons_currencies_switcher_sc' ); 
}


//header wishlist shortcode
if(!function_exists('easybook_addons_header_wishlist_sc')){
    function easybook_addons_header_wishlist_sc($atts, $content = ''){
        ob_start();

        easybook_addons_get_template_part('template-parts/shortcodes/wishlist');
        
        
        $output = ob_get_clean();

        return $output;
    }

    add_shortcode( 'easybook_wishlist', 'easybook_addons_header_wishlist_sc' ); 
}



// dashboard page shortcode
if(!function_exists('easybook_addons_listing_dashboard_page_sc')){
    function easybook_addons_listing_dashboard_page_sc($atts, $content = ''){
        ob_start();

        easybook_addons_get_template_part('templates/dashboard');
        
        $output = ob_get_clean();

        return $output;
    }

    add_shortcode( 'listing_dashboard_page', 'easybook_addons_listing_dashboard_page_sc' ); 
}

// dashboard page shortcode
if(!function_exists('easybook_addons_listing_checkout_page_sc')){
    function easybook_addons_listing_checkout_page_sc($atts, $content = ''){

        ob_start();

        
        $classname = "Esb_Class_Checkout";
        if(isset($_POST['esb-checkout-type']) && $_POST['esb-checkout-type'] != ''){ 
            $classname = "Esb_Class_Checkout_".ucfirst($_POST['esb-checkout-type']);
        }else{
            $classname =  "Esb_Class_Checkout_listing";
        }
        $checkout = new $classname;
        $checkout->breadcrumb();
        $checkout->render();
        $output = ob_get_clean();
        return $output;
    }

    add_shortcode( 'listing_checkout_page', 'easybook_addons_listing_checkout_page_sc' ); 
}

// add new field to submit form
function easybook_addons_submit_addfields_callback($listing_id = 0, $is_edit = false){
    $content_addfields = easybook_addons_get_option('content_addwidgets');
    if(empty($content_addfields) || !is_array($content_addfields)) return;
    foreach ($content_addfields as $widget) {
        ?>
        <!-- profile-edit-container--> 
        <div class="profile-edit-container add-list-container">
            <div class="profile-edit-header fl-wrap">
                <h4><?php echo $widget['widget_title'];?></h4>
            </div>
            <div class="custom-form">
                <div class="listing-additional-fields">
                <?php 
                $name_prefix = 'add_fields_';
                $add_fields_arr = array();
                if(!empty($widget['fields'])){
                    foreach ((array)$widget['fields'] as $key => $field) {
                        $add_fields_arr[] = array(
                            'type' => $field['field_type'],
                            'name' => $field['field_name'],
                            'label' => $field['field_label'],
                            'value' => '',
                            'lvalue'    => ($is_edit? get_post_meta( $listing_id, ESB_META_PREFIX.$name_prefix.$field['field_name'], true ) : ''),
                        );
                    }
                }
                foreach ($add_fields_arr as $addfield) {
                    easybook_addons_get_template_part('templates-inner/add-field-frontend',false,array('name_prefix'=> $name_prefix,'addfield'=>$addfield));
                }
                ?>
                </div>
            </div>
        </div>
        <!-- profile-edit-container end-->  
    <?php
    }
    ?>
    
    <?php
}

add_action( 'wp_footer', function(){
    if( !is_page( esb_addons_get_wpml_option('dashboard_page') ) && easybook_addons_get_option('use_messages') == 'yes' && easybook_addons_get_option('show_fchat') == 'yes' ):
    ?>
        <div id="chat-app"></div>
    <?php 
        
    endif;
    easybook_addons_get_template_part('templates/tmpls');
} );


if(!function_exists('easybook_addons_widget_comment_sc')){
    function easybook_addons_widget_comment_sc($atts, $content = ''){
        ob_start();
        $rating = easybook_addons_get_average_ratings(get_the_ID()); 
        // var_dump( $rating );
        $rating_fields = easybook_addons_get_rating_fields(get_post_meta( get_the_ID(), ESB_META_PREFIX.'listing_type_id', true ));
        ?>
         <?php if(!empty($rating) && easybook_addons_get_option('single_show_rating') == '1' && count($rating_fields) > 1): ?>
            <!--reviews-score-wrap-->   
            <div class="reviews-score-wrap fl-wrap" id="reviews-total-sec">
                    <div class="review-score-total">
                        <span><?php echo $rating['sum']; ?>
                            <strong class="review-text"><?php echo easybook_addons_rating_text($rating['sum']); ?></strong>
                        </span>
                        <a href="#listing-add-review" class="color2-bg"><?php esc_html_e('Add Comment','easybook-add-ons'); ?></a> 
                    </div>
                <div class="review-score-detail">
                    <!-- review-score-detail-list-->
                    <div class="review-score-detail-list">
                        <?php
                       
                        $rating_base = (int)easybook_addons_get_option('rating_base'); 
                        if (!empty($rating_fields)) {
                            foreach ((array)$rating_fields as $key => $field) {
                                ?>
                                <!-- rate item-->
                                <div class="rate-item fl-wrap">
                                    <div class="rate-item-title fl-wrap"><span><?php echo $field['title']; ?></span></div>
                                    <div class="rate-item-bg" data-percent="<?php echo (floatval($rating['values'][$field['fieldName']])/$rating_base)*100 ?>%">
                                                <div class="rate-item-line color-bgs"></div>
                                            </div>
                                    <div class="rate-item-percent"><?php echo floatval($rating['values'][$field['fieldName']]); ?></div>
                                </div>
                                <!-- rate item end-->
                                <?php 
                            }
                        }
                        ?> 
                    </div>
                    <!-- review-score-detail-list end-->
                </div>
            </div>
            <!-- reviews-score-wrap end -->   
        <?php endif ?>
        <?php  
        $output = ob_get_clean();
        return $output;
    }
    add_shortcode( 'easybook_widget_comment', 'easybook_addons_widget_comment_sc' );  
}

